@@ -5,7 +5,7 @@ import pandas as pd
 import os
 from time import sleep
 
-versionNo = "0.1.1"
+versionNo = "0.1.2"
 
 controlEndpoint = "tcp://127.0.0.1:5557"
 dataEndpoint = "tcp://127.0.0.1:5556"
@@ -484,25 +484,4 @@ profile = profile()
 heat = heat()
 bias = bias()
 gas = gas()
-events = eventHandler()
-
-
-heat.data.subscribe()
-bias.data.subscribe()
-gas.data.subscribe()
-gas.msdata.subscribe()
-
-heat.startRamp(500,'rampTime',10)
-sleep(5)
-print(heat.busy)
-
-lastdataHeat = heat.data.getLastData()
-lastDataBias = bias.data.getLastData()
-lastDataGas = gas.data.getLastData()
-lastDataMS = gas.msdata.getLastData()
-
-roundedHeat = heat.data.getDataFrame()
-roundedBias = bias.data.getDataFrame()
-roundedGas = gas.data.getDataFrame()
-roundedMS = gas.msdata.getDataFrame()
-
+events = eventHandler()
\ No newline at end of file
